@@ -293,7 +293,7 @@ static PyObject* Connection_copy_from_csv(PyObject* self, PyObject* args, PyObje
     }
     else
     {
-        Object read_args(Py_BuildValue("(l)", 20));
+        Object read_args(Py_BuildValue("(l)", 200 * 1024));
         if (read_args == 0)
             return 0;
 
@@ -338,6 +338,14 @@ static PyObject* Connection_copy_from_csv(PyObject* self, PyObject* args, PyObje
     Py_BEGIN_ALLOW_THREADS
     final_result = PQgetResult(cnxn->pgconn);
     status = PQresultStatus(final_result);
+
+    // You must call PQgetResult until it returns NULL at the end of each command.
+    for (;;) {
+      PGresult* res = PQgetResult(cnxn->pgconn);
+      if (res == 0)
+        break;
+      PQclear(res);
+    }
     Py_END_ALLOW_THREADS
 
     if (status != PGRES_COMMAND_OK) {
