@@ -21,6 +21,10 @@ struct ResultSet
     PyObject* columns;
     // A tuple of column names, shared among rows.  Will be 0 if there are no column names.
 
+    PyObject* colinfos;
+    // A tuple of colinfo structures, shared among rows.  Will be zero if this has not been
+    // created yet.
+
     Py_ssize_t cFetched;
 
     bool integer_datetimes;
@@ -28,6 +32,7 @@ struct ResultSet
     // connection.
 };
 
+bool ResultSet_Init();
 PyObject* ResultSet_New(Connection* cnxn, PGresult* result);
 
 #endif // RESULTSET_H
